OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "使用者會話意外地過期",
    "Provided email-address is not valid" : "提供的電子郵件地址不是有效的",
    "%s has published the calendar »%s«" : "%s 發佈了日曆 »%s«",
    "Unexpected error sending email. Please contact your administrator." : "傳送電子郵件出現意外的錯誤。請聯絡您的管理者。",
    "Successfully sent email to " : "成功地傳送電子郵件給",
    "Hello," : "嗨，",
    "We wanted to inform you that %s has published the calendar »%s«." : "通知你 %s 發佈了日曆 »%s«.",
    "Open »%s«" : "開啟 »%s«",
    "Cheers!" : "太棒了！",
    "Calendar" : "日曆",
    "A Calendar app for Nextcloud" : "Nextcloud 的日曆應用程式",
    "Previous day" : "前一日",
    "Previous week" : "前週",
    "Previous month" : "前月",
    "Next day" : "隔天",
    "Next week" : "下週",
    "Next month" : "下個月",
    "+ New event" : "+ 新事件",
    "Today" : "今天",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "List" : "清單",
    "Untitled calendar" : "未命名日曆",
    "Edit name" : "編輯名稱",
    "Saving name …" : "儲存名稱 …",
    "Edit color" : "編輯顏色",
    "Saving color …" : "儲存顏色 ...",
    "Copy private link" : "複製私人連結",
    "Download" : "下載",
    "Unshare from me" : "取消與我分享",
    "Delete" : "刪除",
    "An error occurred, unable to change visibility of the calendar." : "發生錯誤，無法改變日曆的能見度",
    "Calendar link copied to clipboard." : "複製日曆連結到剪貼簿",
    "Calendar link could not be copied to clipboard." : "日曆連結無法複製到剪貼簿",
    "An error occurred, unable to rename the calendar." : "發生錯誤，無法重新命名日曆。",
    "Share link" : "分享連結",
    "Publish calendar" : "發布日曆",
    "Publishing calendar" : "正在發布日曆",
    "Copy public link" : "複製公開連結",
    "Send link to calendar via email" : "藉由電子郵件傳送連結到日曆",
    "Enter one address" : "輸入一個位址",
    "Sending email …" : "正在傳送電子郵件 ...",
    "Copy subscription link" : "複製訂閱的連結",
    "Copying link …" : "正在複製連結 ...",
    "Delete share link" : "刪除分享連結",
    "Deleting share link …" : "正在刪除共享連結 ...",
    "Share with users or groups" : "與使用者或群組分享",
    "No users or groups" : "沒有使用者或群組",
    "can edit" : "可編輯",
    "New calendar" : "新日曆",
    "Filename" : "檔案名稱",
    "Cancel" : "取消",
    "Automatic" : "自動",
    "or" : "或者",
    "Actions" : "動作",
    "Show weekends" : "顯示週末",
    "Show week numbers" : "顯示週數",
    "Settings & import" : "設定及匯入",
    "CalDAV link copied to clipboard." : "已複製 CalDAV 連結至剪貼簿",
    "Notification" : "通知",
    "Email" : "Email",
    "Edit time" : "編輯時間",
    "Save time" : "儲存時間",
    "_second_::_seconds_" : ["秒"],
    "_minute_::_minutes_" : ["分鐘"],
    "_hour_::_hours_" : ["時"],
    "_day_::_days_" : ["天"],
    "_week_::_weeks_" : ["週"],
    "Busy" : "忙碌中",
    "Unknown" : "不明",
    "{name} accepted your invitation." : "{name} 已接受您的邀請。",
    "{name} accepted {organizerName}'s invitation." : "{name} 已接受 {organizerName} 的邀請。",
    "{name} declined your invitation." : "{name}已婉拒您的邀請",
    "{name} declined {organizerName}'s invitation." : "{name}已婉拒 {organizerName} 的邀請",
    "Send e-mail" : "傳送電子郵件",
    "Chairperson" : "會長",
    "All day" : "全天",
    "from {startDate}" : "從 {startDate}",
    "to {endDate}" : "至 {endDate}",
    "End repeat" : "停止重複",
    "never" : "永不",
    "after" : "之後",
    "first" : "第一",
    "third" : "第三",
    "fourth" : "第四",
    "fifth" : "第五",
    "Repeat" : "重覆",
    "_month_::_months_" : ["月"],
    "_year_::_years_" : ["年"],
    "Monday" : "週一",
    "Summary" : "摘要",
    "More" : "更多",
    "Save" : "儲存",
    "Update" : "更新",
    "from {formattedDate}" : "從 {formattedDate}",
    "to {formattedDate}" : "至 {formattedDate}",
    "Please enter a valid date" : "請輸入一個有效的日期",
    "Personal" : "私人的",
    "Details" : "詳細資料",
    "Attendees" : "出席者",
    "Reminders" : "提醒",
    "Close" : " 關閉",
    "Show more details" : "顯示更多細節",
    "Download {name}" : "下載 {name}",
    "Anniversary" : "週年",
    "Appointment" : "約會",
    "Business" : "商業",
    "Education" : "教育",
    "Holiday" : "假日",
    "Meeting" : "會議",
    "Not in office" : "不在辦公室",
    "Phone call" : "電話來電",
    "Week {number} of {year}" : "{year} 的第 {number} 週",
    "Daily" : "每日",
    "Weekly" : "每週",
    "next year" : "明年",
    "today" : "今天",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared show only busy" : "分享的時候顯示忙碌中",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "Location" : "地點",
    "Description" : "描述",
    "Status" : "狀態",
    "Confirmed" : "已確認",
    "Tentative" : "暫定的",
    "Categories" : "分類",
    "Movie" : "電影",
    "Cinema" : "電影院",
    "Review" : "檢視",
    "Mail" : "電子郵件",
    "Play" : "播放",
    "Dentist" : "牙醫",
    "Global" : "全球"
},
"nplurals=1; plural=0;");
